@@ -35,14 +35,14 @@ import android.content.pm.PackageManager
 import android.content.res.Configuration
 import android.content.res.Resources
 import android.view.*
+import androidx.core.view.ViewCompat
+import androidx.core.view.WindowInsetsCompat
+import androidx.core.view.updatePadding
 import androidx.preference.PreferenceManager.getDefaultSharedPreferences
 import io.reactivex.disposables.CompositeDisposable
 import io.reactivex.schedulers.Schedulers
 import io.reactivex.android.schedulers.AndroidSchedulers
 
-import com.github.angads25.filepicker.model.DialogConfigs
-import com.github.angads25.filepicker.model.DialogProperties
-import com.github.angads25.filepicker.view.FilePickerDialog
 import com.yariksoffice.lingver.Lingver
 import java.io.BufferedReader
 import java.util.*
@@ -413,15 +413,22 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     override fun onCreateOptionsMenu(menu: Menu?): Boolean {
         menuInflater.inflate(R.menu.menu_main, menu)
 
-
-        menu?.findItem(R.id.action_subscribe)?.isEnabled=false
-        subscriptionManager.ready.observe(this) {
+        val onSubscriptionManagerReadyChange: (Boolean) -> Unit = {
             if (subscriptionManager.subscribed.value == false) {
                 menu?.findItem(R.id.action_subscribe)?.isEnabled = it
             }
         }
 
-        subscriptionManager.subscribed.observe(this) {
+        menu?.findItem(R.id.action_subscribe)?.isEnabled=false
+        subscriptionManager.ready.value?.let {
+            onSubscriptionManagerReadyChange(it)
+        }
+
+        subscriptionManager.ready.observe(this) {
+            onSubscriptionManagerReadyChange(it)
+        }
+
+        val onSubscriptionManagerSubscribedChange: (Boolean) -> Unit = {
             if (it) {
                 if (subscriptionManager.isLifetime.value == true) {
                     menu?.findItem(R.id.action_subscribe).let { item ->
@@ -456,6 +463,14 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             }
         }
 
+        subscriptionManager.subscribed.value?.let {
+            onSubscriptionManagerSubscribedChange(it)
+        }
+
+        subscriptionManager.subscribed.observe(this) {
+            onSubscriptionManagerSubscribedChange(it)
+        }
+
         menu?.findItem(R.id.action_about).let {
             it?.setOnMenuItemClickListener {
                 val intent = Intent(this,  AboutActivity::class.java)
@@ -522,6 +537,24 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         activityReportListBinding = ActivityReportListBinding.inflate(layoutInflater)
         helloLayoutBinding = HelloLayoutBinding.inflate(layoutInflater)
 
+        ViewCompat.setOnApplyWindowInsetsListener(activityReportListBinding.appBar) { v: View, insets: WindowInsetsCompat ->
+            val bars = insets.getInsets(WindowInsetsCompat.Type.systemBars()
+                    or WindowInsetsCompat.Type.displayCutout())
+            v.updatePadding(
+                left = bars.left,
+                top = bars.top,
+                right = bars.right,
+            )
+            WindowInsetsCompat.CONSUMED
+        }
+        ViewCompat.setOnApplyWindowInsetsListener(activityReportListBinding.frameLayout) { v: View, insets: WindowInsetsCompat ->
+            val bars = insets.getInsets(WindowInsetsCompat.Type.systemBars()
+                    or WindowInsetsCompat.Type.displayCutout())
+            v.updatePadding(
+                bottom = bars.bottom,
+            )
+            WindowInsetsCompat.CONSUMED
+        }
 
         setContentView(activityReportListBinding.root)
 
@@ -531,56 +564,35 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         updatePreferences()
 
         subscriptionManager = SubscriptionManager.getInstance(application)
-        lifecycle.addObserver(subscriptionManager)
 
         setLocale()
-        subscriptionManager.subscribed.observe(this) {
-            if (it==true) {
+
+        val onSubscriptionManagerSubscribedChange: (Boolean) -> Unit = {
+            if (it) {
                 applyUiMode()
                 setPrefLocale()
             }
         }
 
+        subscriptionManager.subscribed.value?.let {
+            onSubscriptionManagerSubscribedChange(it)
+        }
+
+        subscriptionManager.subscribed.observe(this) {
+            onSubscriptionManagerSubscribedChange(it)
+        }
+
         val viewModelFactory = Injection.provideViewModelFactory(this)
         reportModel = ViewModelProvider(this, viewModelFactory)[ReportViewModel::class.java]
 
         activityReportListBinding.addButton.setOnClickListener {
-            if (Build.VERSION.SDK_INT >= 20) { // Official Android FileChooser is buggy on Android 4.4 (19)
-                val intent = Intent(Intent.ACTION_GET_CONTENT)
+            val intent = Intent(Intent.ACTION_GET_CONTENT)
 
-                intent.addCategory(Intent.CATEGORY_OPENABLE)
-                intent.type = "*/*"
-                intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
+            intent.addCategory(Intent.CATEGORY_OPENABLE)
+            intent.type = "*/*"
+            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
 
-                startActivityForResult(intent, OPEN_FILE_REQUEST)
-            } else {
-                if (Environment.getExternalStorageState() in setOf(Environment.MEDIA_MOUNTED, Environment.MEDIA_MOUNTED_READ_ONLY)) {
-                    val properties = DialogProperties()
-                    properties.selection_mode = DialogConfigs.MULTI_MODE
-                    properties.selection_type = DialogConfigs.FILE_SELECT
-                    properties.root = File(DialogConfigs.DEFAULT_DIR)
-                    properties.error_dir = File(DialogConfigs.DEFAULT_DIR)
-                    properties.offset = File(DialogConfigs.DEFAULT_DIR)
-                    properties.extensions = null
-
-                    val dialog = FilePickerDialog(this, properties)
-                    dialog.setTitle(R.string.open_title)
-
-                    dialog.setDialogSelectionListener { files: Array<String> ->
-                        var uris: Array<Uri> = arrayOf()
-
-                        files.forEach { uri: String ->
-                            uris += Uri.parse("file://$uri")
-                        }
-                        AddFile().execute(*(uris))
-                    }
-
-                    dialog.show()
-                } else {
-                    val toast = Toast.makeText(applicationContext, R.string.media_error_text, Toast.LENGTH_LONG)
-                    toast.show()
-                }
-            }
+            startActivityForResult(intent, OPEN_FILE_REQUEST)
         }
         activityReportListBinding.reportListLayout.clearBtn.setOnClickListener {
             disposable.add(reportModel.deleteAllReports()
@@ -609,7 +621,17 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         if (activityReportListBinding.reportListLayout.reportDetailContainer != null)
             twoPane = true
 
-         setupRecyclerView(activityReportListBinding.reportListLayout.reportList)
+        if (!twoPane) {
+            val fragment = supportFragmentManager.findFragmentById(R.id.report_detail_container)
+            if (fragment != null) {
+                supportFragmentManager
+                    .beginTransaction()
+                    .detach(fragment)
+                    .commit()
+            }
+        }
+
+        setupRecyclerView(activityReportListBinding.reportListLayout.reportList)
 
         onNewIntent(intent)
     }
