@@ -80,6 +80,8 @@ Preferences::Preferences(QSettings* settings, Core* C, QWidget *parent) :
     ui->informTimestamp->setChecked(settings->value("informTimestamp",false).toBool());
     ui->displayCaptions->setCurrentIndex(settings->value("displayCaptions",1).toInt());
     ui->legacyStreamDisplay->setChecked(settings->value("legacyStreamDisplay",false).toBool());
+    ui->coverData->setChecked(settings->value("coverData",false).toBool());
+    ui->testContinuousFileNames->setChecked(settings->value("testContinuousFileNames",false).toBool());
     ui->enableFFmpeg->setChecked(settings->value("enableFFmpeg",false).toBool());
     ui->Graph_Adm_ShowTrackUIDs->setChecked(settings->value("Graph_Adm_ShowTrackUIDs",false).toBool());
     ui->Graph_Adm_ShowChannelFormats->setChecked(settings->value("Graph_Adm_ShowChannelFormats",false).toBool());
@@ -156,6 +158,8 @@ void Preferences::saveSettings() {
     settings->setValue("informTimestamp",ui->informTimestamp->isChecked());
     settings->setValue("displayCaptions",ui->displayCaptions->currentIndex());
     settings->setValue("legacyStreamDisplay",ui->legacyStreamDisplay->isChecked());
+    settings->setValue("coverData",ui->coverData->isChecked());
+    settings->setValue("testContinuousFileNames",ui->testContinuousFileNames->isChecked());
     settings->setValue("enableFFmpeg",ui->enableFFmpeg->isChecked());
     settings->setValue("Graph_Adm_ShowTrackUIDs",ui->Graph_Adm_ShowTrackUIDs->isChecked());
     settings->setValue("Graph_Adm_ShowChannelFormats",ui->Graph_Adm_ShowChannelFormats->isChecked());
