@@ -390,6 +390,16 @@ void __fastcall TPreferencesF::CB_InscrireShell_FolderClick(TObject *Sender)
 
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TPreferencesF::CB_InscrireShell_RetainLegacyClick(TObject *Sender)
+{
+    //Shell extension
+    if (CB_InscrireShell_RetainLegacy->Checked)
+        Prefs->Config(__T("ShellExtension_RetainLegacy"), 1)=__T("1");
+    else
+        Prefs->Config(__T("ShellExtension_RetainLegacy"), 1)=__T("0");
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::CB_InfoTipClick(TObject *Sender)
 {
@@ -651,6 +661,7 @@ void __fastcall TPreferencesF::Setup_GeneralShow(TObject *Sender)
     CB_CheckUpdate->Checked=Prefs->Config(__T("CheckUpdate")).To_int32s();
     CB_InscrireShell->Checked=Prefs->Config(__T("ShellExtension")).To_int32s(); //Lecture Shell extension
     CB_InscrireShell_Folder->Checked=Prefs->Config(__T("ShellExtension_Folder")).To_int32s(); //Lecture Shell extension
+    CB_InscrireShell_RetainLegacy->Checked=Prefs->Config(__T("ShellExtension_RetainLegacy")).To_int32s(); //Lecture Shell extension
     CB_InfoTip->Checked=Prefs->Config(__T("ShellInfoTip")).To_int32s(); //Lecture Shell extension
 }
 
@@ -703,7 +714,7 @@ void __fastcall TPreferencesF::GUI_Configure()
     Tree->FullExpand();
     Page->ActivePage=Setup;
 
-    //Enable separate instance option if modern shell extension is installed
+    //Enable additional options if modern shell extension is installed
     TRegistry* Reg = new TRegistry;
     try {
         Reg->RootKey = HKEY_CLASSES_ROOT;
@@ -714,12 +725,13 @@ void __fastcall TPreferencesF::GUI_Configure()
                 if (Reg->ValueExists("ShellExtension_SeparateInstance"))
                     CB_InscrireShell_SeparateInstance->Checked=Reg->ReadInteger("ShellExtension_SeparateInstance");
             }
+            CB_InscrireShell_RetainLegacy->Visible=true;
         }
     } catch (...) {}
     delete Reg;
 
     //Move InfoTip option up to prevent blank space if there is a space
-    if (!CB_InscrireShell_SeparateInstance->Visible)
+    if (!CB_InscrireShell_SeparateInstance->Visible && !CB_InscrireShell_RetainLegacy->Visible)
         CB_InfoTip->Top=CB_InscrireShell_Folder->Top+CB_InscrireShell_Folder->Height*0.9;
 
     //Translation
@@ -799,6 +811,7 @@ void __fastcall TPreferencesF::GUI_Configure()
     Setup_Advanced->Caption=Prefs->Translate(__T("Advanced")).c_str();
     CB_InscrireShell->Caption=Prefs->Translate(__T("Shell extension")).c_str();
     CB_InscrireShell_Folder->Caption=Prefs->Translate(__T("Shell extension, folder")).c_str();
+    CB_InscrireShell_SeparateInstance->Caption=Prefs->Translate(__T("Shell extension, separate instance")).c_str();
     CB_InfoTip->Caption=Prefs->Translate(__T("Shell InfoTip")).c_str();
     CB_ShowToolBar->Caption=Prefs->Translate(__T("Show toolbar")).c_str();
     CB_ShowMenu->Caption=Prefs->Translate(__T("Show menu")).c_str();
@@ -806,6 +819,7 @@ void __fastcall TPreferencesF::GUI_Configure()
     Advanced_InformVersion->Caption=Prefs->Translate(__T("Add version to text output")).c_str();
     Advanced_InformTimestamp->Caption=Prefs->Translate(__T("Add creation date to text output")).c_str();
     Advanced_EnableFfmpeg->Caption=Prefs->Translate(__T("Enable FFmpeg plugin")).c_str();
+    Advanced_LegacyStreamDisplay->Caption=Prefs->Translate(__T("LegacyStreamDisplay")).c_str();
     Advanced_DisplayCaptions_Caption->Caption=Prefs->Translate(__T("DisplayCaptions")).c_str();
     Advanced_DisplayCaptions_Sel->Items->Clear();
     Advanced_DisplayCaptions_Sel->Items->Add(Prefs->Translate(__T("DisplayCaptions_Content")).c_str());
